/*
** iplog.h - data used by all iplog modules.
** Copyright (C) 1999,2000 Ryan McCabe <odin@numb.org>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License, version 2,
** as published by the Free Software Foundation.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
**
** $Id: iplog.h,v 1.8 2000/01/14 06:17:24 odin Exp $
*/

#ifndef __IPLOG_H
#define __IPLOG_H

#define FACILITY LOG_DAEMON
#define PRIORITY LOG_NOTICE

/*
** Making these smaller will probably do bad things.
*/
#define MAX_HSTLEN	256
#define MAX_SRVLEN	128
#define MAX_PRTLEN	32
#define MAX_IPLEN	16
#define MAX_PORT	0xffff
#define MIN_PORT	0

#define xfree(x) do { free(x); (x) = NULL; } while (0)

#define DNS_HASH(x, y) ((((x) >> 24) + ((x) >> 16)) & ((y) - 1))

/*
** This is temporary
*/
#define SCAN_HASH(x, y, z) (((x) ^ (y)) & ((z) - 1))

#ifndef min
#	define min(x,y) ((x) < (y) ? (x) : (y))
#endif

typedef enum {
	FALSE = 0, false = 0,
	TRUE = 1, true = 1
} bool;

#ifndef HAVE_U_INT32_T
#	define u_int16_t uint16_t
#	define u_int32_t uint32_t
#endif

#if defined(__svr4__)
#	include <pthread.h>
#	ifndef _UINT16_T
typedef unsigned short uint16_t;
#		define _UINT16_T
#	endif
#endif		/*__svr4__*/


typedef u_int16_t port_t;
typedef u_int32_t addr_t;
typedef u_int32_t mask_t;

struct generic_data {
	struct generic_data *next;
};

#ifndef HAVE_DPRINTF
int dprintf(int fd, const char *fmt, ...);
#endif

void *xmalloc(size_t size);
void *xcalloc(size_t nmemb, size_t size);
char *xstrdup(const char *s);
char *xstrncpy(char *dest, const char *src, size_t n);
char *xstrncat(char *dest, const char *src, size_t n);
void fork_to_back(void);
u_char *serv_lookup(port_t port, const u_char *proto, u_char *buf, size_t len);
u_char *proto_lookup(int proto, u_char *buf, size_t len);
void drop_privs(const u_char *user, const u_char *group);
bool valid_number(const u_char *p);
void fatal(const u_char *fmt, ...);
int get_line(FILE *fp, u_char *buf, size_t len);

void *list_append(const void *data, void **head_ptr, size_t len);
void *list_prepend(const void *data, void **head_ptr, size_t len);
void *list_delete(void *node, void **head_ptr);
void list_destroy(void *list_head, void (*cleanup)(void *));

int in_cksum(u_short *addr, int len);

__inline__ bool tcp_res(void);
__inline__ bool udp_res(void);
__inline__ bool icmp_res(void);

void mysyslog(const char *fmt, ...);
void myopenlog(const char *name, int option);
void mycloselog(void);

void get_options(int argc, char * const argv[]);

void write_lockfile(void);
void kill_iplog(int sig);
bool get_raw_sock(void);
void expire_dns(void);

bool is_listening(port_t port);
void *get_ident_data(void *data);

#ifndef HAVE_LOCALTIME_R
struct tm *localtime_r(const time_t *time, struct tm *result);
#endif

#define __FAVOR_BSD
#include <netinet/in_systm.h>
#include <netinet/in.h>
#include <netinet/ip.h>
#include <netinet/tcp.h>
#include <arpa/inet.h>

#include <netinet/udp.h>

int tcp_parser(const struct ip *ip);
int udp_parser(const struct ip *ip);
int icmp_parser(const struct ip *ip);

u_char *inet_ntoa_r(const struct in_addr *in, u_char *buf, size_t len);
u_char *host_lookup(const struct in_addr *in, bool resolv, u_char *buf, size_t len);
u_char *_host_lookup(const struct in_addr *in, u_char *buf, size_t len);

#endif /* __IPLOG_H */

/* vim:ts=4:sw=8:tw=0 */
